# dotfiles

My personalized set of configurations.

## alacritty

I'll add more themes as I try them out. I use Hack Nerd Font as it has been a solid choice for many years.

### Requirements

- [Hack Nerd Font](https://www.nerdfonts.com/)

### Setup

```
$ cp -r alacritty/ ~/.config/.
$ ln -s ~/.config/alacritty/alacritty-<THEME>.toml ~/.config/alacritty/alacritty.toml
```

## nvim (Neovim)

Here are the plugins I'm currently using:

- [lazy](https://github.com/folke/lazy.nvim) - Neovim plugin manager.
- [autopairs](https://github.com/windwp/nvim-autopairs) - "Autopairs" parentheses/brackets/braces/etc.
- [cmp](https://github.com/hrsh7th/nvim-cmp) - Autocompletion.
- [colorizer](https://github.com/norcalli/nvim-colorizer.lua) - Syntax highlighting.
- [conform](https://github.com/stevearc/conform.nvim) - Autoformatting.
- [gitsigns](https://github.com/lewis6991/gitsigns.nvim) - Git integration within buffer.
- [indent-blankline](https://github.com/lukas-reineke/indent-blankline.nvim) - Indentation guides.
- [lspconfig](https://github.com/neovim/nvim-lspconfig) - Quick setup for LSP.
- [lualine](https://github.com/nvim-lualine/lualine.nvim) - Helpful status line.
- [mason](https://github.com/williamboman/mason.nvim) - Plugin manager specific to external tools (LSP/linters/formatters/etc.)
- [neo-tree](https://github.com/nvim-neo-tree/neo-tree.nvim) - File manager.
- [telescope](https://github.com/nvim-telescope/telescope.nvim) - Fuzzy finder.
- [toggleterm](https://github.com/akinsho/toggleterm.nvim) - Terminal switcher.
- [tree-sitter](https://github.com/nvim-treesitter/nvim-treesitter) - Syntax parsing for opened files.

### Requirements

- [luarocks](https://github.com/luarocks/luarocks)
- npm

### Setup

A couple of the plugins need some Node.JS packages installed first.

```
$ sudo npm install -g tree-sitter tree-sitter-cli typescript typescript-language-server
```

## pipewire

These are used primarily on non-systemd setups.

### Requirements

- [pipewire-pulse](https://docs.pipewire.org/page_man_pipewire-pulse_1.html)
- [wireplumber](https://gitlab.freedesktop.org/pipewire/wireplumber)

### Setup

```
$ cp -r pipewire ~/.config/.
```

## starship

I use the same theme for all my terminals, but change the color based on the machine.

### Requirements

- [Hack Nerd Font](https://www.nerdfonts.com/)

### Setup

```
$ cp starship/starship-<COLOR>.toml ~/.config/starship.toml
```

## tmux

Very minimal for now.

### Requirements

None.

### Setup

```
$ cp -r tmux/ ~/.config/.
```

## wireplumber

Usually you don't need anything specific in the wireplumber setup, but I have custom bluetooth configurations for my headsets.

### Requirements

None.

### Setup

```
$ cp -r wireplumber ~/.config/.
```

## xdg-user-dirs

Like everything else Unix-like, I prefer my home folders all-lowercased.

### Requirements

- [xdg-user-dirs](https://wiki.archlinux.org/title/XDG_user_directories)

### Setup

```
$ cp xdg-user-dirs/* ~/.config/.
$ cd ~
$ mkdir desktop documents downloads music pictures public templates videos
$ xdg-user-dirs-update
```
